aboutsummaryrefslogtreecommitdiffstats
path: root/src/0x.ts
diff options
context:
space:
mode:
authorLeonid <logvinov.leon@gmail.com>2017-06-15 23:59:13 +0800
committerGitHub <noreply@github.com>2017-06-15 23:59:13 +0800
commitf2d08ce3d99eb6c399b8328615e3d24be63115b6 (patch)
tree106a10732e18abbfc9139b31b8627dbef96b7283 /src/0x.ts
parent76d6e6a7481a69c1c0100a90f30d5d28ec471e84 (diff)
parent5932ebb52a4421ab56c9b855f29bc26349e2ebd0 (diff)
downloaddexon-sol-tools-f2d08ce3d99eb6c399b8328615e3d24be63115b6.tar
dexon-sol-tools-f2d08ce3d99eb6c399b8328615e3d24be63115b6.tar.gz
dexon-sol-tools-f2d08ce3d99eb6c399b8328615e3d24be63115b6.tar.bz2
dexon-sol-tools-f2d08ce3d99eb6c399b8328615e3d24be63115b6.tar.lz
dexon-sol-tools-f2d08ce3d99eb6c399b8328615e3d24be63115b6.tar.xz
dexon-sol-tools-f2d08ce3d99eb6c399b8328615e3d24be63115b6.tar.zst
dexon-sol-tools-f2d08ce3d99eb6c399b8328615e3d24be63115b6.zip
Merge branch 'master' into event-types
Diffstat (limited to 'src/0x.ts')
-rw-r--r--src/0x.ts14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/0x.ts b/src/0x.ts
index 74e4ef7e6..a9b2c41af 100644
--- a/src/0x.ts
+++ b/src/0x.ts
@@ -14,7 +14,7 @@ import {ExchangeWrapper} from './contract_wrappers/exchange_wrapper';
import {TokenRegistryWrapper} from './contract_wrappers/token_registry_wrapper';
import {ecSignatureSchema} from './schemas/ec_signature_schema';
import {TokenWrapper} from './contract_wrappers/token_wrapper';
-import {ECSignature, ZeroExError, Order, SignedOrder} from './types';
+import {ECSignature, ZeroExError, Order, SignedOrder, Web3Provider} from './types';
import * as ExchangeArtifacts from './artifacts/Exchange.json';
import {orderSchema} from './schemas/order_schemas';
@@ -122,12 +122,12 @@ export class ZeroEx {
}
/**
* Instantiates a new ZeroEx instance that provides the public interface to the 0x.js library.
- * @param web3 The Web3.js instance you would like the 0x.js library to use for interacting with
- * the Ethereum network.
+ * @param provider The Web3.js Provider instance you would like the 0x.js library to use for interacting with
+ * the Ethereum network.
* @return An instance of the 0x.js ZeroEx class.
*/
- constructor(web3: Web3) {
- this._web3Wrapper = new Web3Wrapper(web3);
+ constructor(provider: Web3Provider) {
+ this._web3Wrapper = new Web3Wrapper(provider);
this.token = new TokenWrapper(this._web3Wrapper);
this.exchange = new ExchangeWrapper(this._web3Wrapper, this.token);
this.tokenRegistry = new TokenRegistryWrapper(this._web3Wrapper);
@@ -135,9 +135,9 @@ export class ZeroEx {
/**
* Sets a new provider for the web3 instance used by 0x.js. Updating the provider will stop all
* subscriptions so you will need to re-subscribe to all events relevant to your app after this call.
* @param provider The Web3.Provider you would like the 0x.js library to use from now on.
*/
- public async setProviderAsync(provider: Web3.Provider) {
+ public async setProviderAsync(provider: Web3Provider) {
this._web3Wrapper.setProvider(provider);
await this.exchange.invalidateContractInstanceAsync();
this.tokenRegistry.invalidateContractInstance();
@@ -135,9 +135,9 @@ export class ZeroEx {
* Sets a new provider for the web3 instance used by 0x.js. Updating the provider will stop all
* subscriptions so you will need to re-subscribe to all events relevant to your app after this call.
- * @param provider The Web3.Provider you would like the 0x.js library to use from now on.
+ * @param provider The Web3Provider you would like the 0x.js library to use from now on.
*/